/*
* An implementation of the SHA-384 and 512 hash function, this is endian neutral
* so should work just about anywhere.
*
* This code works much like the MD5 code provided by RSA.  You sha_init()
* a "sha_state" then sha_process() the bytes you want and sha_done() to get
* the output.
*
* Revised Code:  Complies to SHA-384 and 512 standard now.
*
* Tom St Denis, Oct 12th 2000 (SHA-256)
* bubba, Oct 16th 2000 (SHA-512)
* David Crick, Oct 16th 2000 (SHA-384)
* Disastry, Aug 30th 2001 (SHA-384 and 512, self test, converted to 32bit)
* Disastry, Jan 16th 2002 (128 bit length)
* Disastry, Apr 22th 2002 ("off-by-one" bug fixed (output was wrong for length = 111 + 128 * n , where n = 0,1,2,3,...)
* */

#include "usuals.h"  /* typedefs for byte, word16, boolean, etc. */
#define UINT32 word32

typedef struct {
   UINT32 state [16], length0, length1, length2, length3, curlen;
   unsigned char buf [128];
   } sha_state512;
typedef sha_state512 sha_state384;

void sha_init384(sha_state384 *md);
void sha_init512(sha_state512 *md);
void sha_process384(sha_state384 *md, unsigned char *buf, unsigned len);
void sha_process512(sha_state512 *md, unsigned char *buf, unsigned len);
void sha_done384(sha_state384 *md, unsigned char *hash);
void sha_done512(sha_state512 *md, unsigned char *hash);

/* sha a block of memory */
void sha_memory384(unsigned char *buf, unsigned len, unsigned char *hash);
void sha_memory512(unsigned char *buf, unsigned len, unsigned char *hash);
/* sha a file, return 1 if ok */
int sha_file384(char *filename, unsigned char *hash);
int sha_file512(char *filename, unsigned char *hash);
